@@ -113,7 +113,7 @@ class MigrationHubRefactorSpacesClient(BaseClient):
         Name: str,
         ProxyType: Literal["API_GATEWAY"],
         VpcId: str,
-        ApiGatewayProxy: "ApiGatewayProxyInputTypeDef" = ...,
+        ApiGatewayProxy: ApiGatewayProxyInputTypeDef = ...,
         ClientToken: str = ...,
         Tags: Mapping[str, str] = ...
     ) -> CreateApplicationResponseTypeDef:
@@ -149,7 +149,7 @@ class MigrationHubRefactorSpacesClient(BaseClient):
         ServiceIdentifier: str,
         ClientToken: str = ...,
         Tags: Mapping[str, str] = ...,
-        UriPathRoute: "UriPathRouteInputTypeDef" = ...
+        UriPathRoute: UriPathRouteInputTypeDef = ...
     ) -> CreateRouteResponseTypeDef:
         """
         Creates an Amazon Web Services Migration Hub Refactor Spaces route.
@@ -167,9 +167,9 @@ class MigrationHubRefactorSpacesClient(BaseClient):
         Name: str,
         ClientToken: str = ...,
         Description: str = ...,
-        LambdaEndpoint: "LambdaEndpointInputTypeDef" = ...,
+        LambdaEndpoint: LambdaEndpointInputTypeDef = ...,
         Tags: Mapping[str, str] = ...,
-        UrlEndpoint: "UrlEndpointInputTypeDef" = ...,
+        UrlEndpoint: UrlEndpointInputTypeDef = ...,
         VpcId: str = ...
     ) -> CreateServiceResponseTypeDef:
         """
